@@ -147,18 +147,11 @@ PHP_FUNCTION(ftp_connect)
 		RETURN_THROWS();
 	}
 
-	const zend_long timeoutmax = (zend_long)((double) PHP_TIMEOUT_ULL_MAX / 1000000.0);
-
 	if (timeout_sec <= 0) {
 		zend_argument_value_error(3, "must be greater than 0");
 		RETURN_THROWS();
 	}
 
-	if (timeout_sec >= timeoutmax) {
-		zend_argument_value_error(3, "must be less than " ZEND_LONG_FMT, timeoutmax);
-		RETURN_THROWS();
-	}
-
 	/* connect */
 	if (!(ftp = ftp_open(host, (short)port, timeout_sec))) {
 		RETURN_FALSE;
@@ -816,7 +809,7 @@ PHP_FUNCTION(ftp_nb_get)
 }
 /* }}} */
 
-/* {{{ Continues to retrieve or send a file in non-blocking mode */
+/* {{{ Continues retrieving/sending a file nbronously */
 PHP_FUNCTION(ftp_nb_continue)
 {
 	zval		*z_ftp;
@@ -829,7 +822,7 @@ PHP_FUNCTION(ftp_nb_continue)
 	GET_FTPBUF(ftp, z_ftp);
 
 	if (!ftp->nb) {
-		php_error_docref(NULL, E_WARNING, "No non-blocking transfer to continue");
+		php_error_docref(NULL, E_WARNING, "No nbronous transfer to continue");
 		RETURN_LONG(PHP_FTP_FAILED);
 	}
 
