@@ -57,7 +57,7 @@ const GMP_BIG_ENDIAN = UNKNOWN;
  */
 const GMP_NATIVE_ENDIAN = UNKNOWN;
 
-class GMP
+final class GMP
 {
     public function __construct(int|string $num = 0, int $base = 0) {}
 
