@@ -40,7 +40,6 @@
 #ifdef LIBXML_SCHEMAS_ENABLED
 #include <libxml/relaxng.h>
 #include <libxml/xmlschemas.h>
-#include <libxml/xmlschemastypes.h>
 #endif
 
 #include "php_libxml.h"
@@ -525,7 +524,6 @@ static int php_libxml_streams_IO_close(void *context)
 	return php_stream_close((php_stream*)context);
 }
 
-/* TODO: This needs to be replaced by context-specific APIs in the future! */
 static xmlParserInputBufferPtr
 php_libxml_input_buffer_create_filename(const char *URI, xmlCharEncoding enc)
 {
@@ -559,10 +557,13 @@ php_libxml_input_buffer_create_filename(const char *URI, xmlCharEncoding enc)
 	}
 
 	/* Allocate the Input buffer front-end. */
-	ret = xmlParserInputBufferCreateIO(php_libxml_streams_IO_read, php_libxml_streams_IO_close, context, enc);
-	if (ret == NULL) {
+	ret = xmlAllocParserInputBuffer(enc);
+	if (ret != NULL) {
+		ret->context = context;
+		ret->readcallback = php_libxml_streams_IO_read;
+		ret->closecallback = php_libxml_streams_IO_close;
+	} else
 		php_libxml_streams_IO_close(context);
-	}
 
 	return(ret);
 }
@@ -609,10 +610,11 @@ php_libxml_output_buffer_create_filename(const char *URI,
 	}
 
 	/* Allocate the Output buffer front-end. */
-	ret = xmlOutputBufferCreateIO(php_libxml_streams_IO_write, php_libxml_streams_IO_close, context, encoder);
-	if (ret == NULL) {
-		php_libxml_streams_IO_close(context);
-		goto err;
+	ret = xmlAllocOutputBuffer(encoder);
+	if (ret != NULL) {
+		ret->context = context;
+		ret->writecallback = php_libxml_streams_IO_write;
+		ret->closecallback = php_libxml_streams_IO_close;
 	}
 
 	return(ret);
@@ -799,7 +801,6 @@ is_string:
 				zend_string_release(callable_name);
 				zval_ptr_dtor(&callable);
 			} else {
-#if LIBXML_VERSION < 21400
 				/* TODO: allow storing the encoding in the stream context? */
 				xmlCharEncoding enc = XML_CHAR_ENCODING_NONE;
 				xmlParserInputBufferPtr pib = xmlAllocParserInputBuffer(enc);
@@ -809,24 +810,15 @@ is_string:
 				} else {
 					/* make stream not being closed when the zval is freed */
 					GC_ADDREF(stream->res);
-
-					ZEND_DIAGNOSTIC_IGNORED_START("-Wdeprecated-declarations")
 					pib->context = stream;
 					pib->readcallback = php_libxml_streams_IO_read;
 					pib->closecallback = php_libxml_streams_IO_close;
-					ZEND_DIAGNOSTIC_IGNORED_END
 
 					ret = xmlNewIOInputStream(context, pib, enc);
 					if (ret == NULL) {
 						xmlFreeParserInputBuffer(pib);
 					}
 				}
-#else
-				/* make stream not being closed when the zval is freed */
-				GC_ADDREF(stream->res);
-				ret = xmlNewInputFromIO(NULL, php_libxml_streams_IO_read, php_libxml_streams_IO_close, stream, 0);
-				/* Note: if ret == NULL, the close operation will be executed, so don't DELREF stream->res upon failure! */
-#endif
 			}
 		} else if (Z_TYPE(retval) != IS_NULL) {
 			/* retval not string nor resource nor null; convert to string */
@@ -937,16 +929,7 @@ PHP_LIBXML_API void php_libxml_initialize(void)
 	if (!_php_libxml_initialized) {
 		/* we should be the only one's to ever init!! */
 		ZEND_IGNORE_LEAKS_BEGIN();
-
 		xmlInitParser();
-#ifdef ZTS
-# ifdef LIBXML_SCHEMAS_ENABLED
-		xmlSchemaInitTypes();
-# endif
-# ifdef LIBXML_RELAXNG_ENABLED
-		xmlRelaxNGInitTypes();
-# endif
-#endif
 		ZEND_IGNORE_LEAKS_END();
 
 		_php_libxml_default_entity_loader = xmlGetExternalEntityLoader();
