@@ -367,14 +367,22 @@ function parseSpecialCasing(UnicodeData $data, string $input) : void {
 
 function parseDerivedCoreProperties(UnicodeData $data, string $input) : void {
     foreach (parseDataFile($input) as $fields) {
-        if (count($fields) != 2) {
-            throw new Exception("Line does not contain 2 fields");
+        $fieldCount = count($fields);
+        if ($fieldCount != 2 && $fieldCount !== 3) {
+            throw new Exception("Line does not contain 2 or 3 fields");
         }
 
-        $property = $fields[1];
-        if ($property != 'Cased' && $property != 'Case_Ignorable') {
+        $usedProperties = ['Cased', 'Case_Ignorable'];
+        if (isset($fields[2]) && in_array($fields[2], $usedProperties, true)) {
+            $property = $fields[2];
+        }
+        elseif (!in_array($fields[1], $usedProperties, true)) {
             continue;
         }
+        else{
+            $property = $fields[1];
+        }
+
 
         $range = explode('..', $fields[0]);
         if (count($range) == 2) {
@@ -700,7 +708,7 @@ function generateMPH(array $map, bool $fast) {
 }
 
 function generateEastAsianWidthData(array $wideRanges) {
-      $result = <<<'HEADER'
+    $result = <<<'HEADER'
 /* This file was generated by ext/mbstring/ucgendat/ucgendat.php.
  *
  *                     DO NOT EDIT THIS FILE!
@@ -717,12 +725,17 @@ function generateEastAsianWidthData(array $wideRanges) {
  * which should be displayed as double-width.
  */
 
+HEADER;
+
+    $result .= "\n#define FIRST_DOUBLEWIDTH_CODEPOINT 0x" . dechex($wideRanges[0]->start) . "\n\n";
+
+    $result .= <<<'TABLESTART'
 static const struct {
 	int begin;
 	int end;
 } mbfl_eaw_table[] = {
 
-HEADER;
+TABLESTART;
 
     foreach ($wideRanges as $range) {
         $startCode = dechex($range->start);
