@@ -792,21 +792,26 @@ IR_ALWAYS_INLINE bool ir_is_good_bb_order(ir_ctx *ctx, uint32_t b, ir_block *bb,
 	ir_ref *p = insn->ops + 1;
 
 	if (n == 1) {
-		return *p < start;
+		return ctx->cfg_map[*p] < b;
 	} else {
 		IR_ASSERT(n > 1);
 		for (; n > 0; p++, n--) {
 			ir_ref input = *p;
-			if (input < start) {
-				/* ordered */
-			} else if ((bb->flags & IR_BB_LOOP_HEADER)
-			  && (ctx->cfg_map[input] == b || ctx->cfg_blocks[ctx->cfg_map[input]].loop_header == b)) {
-				/* back-edge of reducible loop */
-			} else if ((bb->flags & IR_BB_IRREDUCIBLE_LOOP)
-			  && (ctx->cfg_blocks[ctx->cfg_map[input]].loop_header == ctx->cfg_blocks[b].loop_header)) {
-				/* closing edge of irreducible loop */
-			} else {
-				return 0;
+
+			if (!IR_IS_CONST_REF(input)) {
+				uint32_t input_b = ctx->cfg_map[input];
+
+				if (input_b < b) {
+					/* ordered */
+				} else if ((bb->flags & IR_BB_LOOP_HEADER)
+				  && (input_b == b || ctx->cfg_blocks[input_b].loop_header == b)) {
+					/* back-edge of reducible loop */
+				} else if ((bb->flags & IR_BB_IRREDUCIBLE_LOOP)
+				  && (ctx->cfg_blocks[input_b].loop_header == bb->loop_header)) {
+					/* closing edge of irreducible loop */
+				} else {
+					return 0;
+				}
 			}
 		}
 		return 1;
@@ -925,121 +930,54 @@ int ir_schedule(ir_ctx *ctx)
 	ir_ref *_xlat;
 	ir_ref *edges;
 	ir_ref prev_b_end;
-	uint32_t b, prev_b;
+	uint32_t b;
 	uint32_t *_blocks = ctx->cfg_map;
 	ir_ref *_next = ir_mem_malloc(ctx->insns_count * sizeof(ir_ref));
 	ir_ref *_prev = ir_mem_malloc(ctx->insns_count * sizeof(ir_ref));
-	ir_ref _move_down = 0;
 	ir_block *bb;
 	ir_insn *insn, *new_insn;
 	ir_use_list *lists, *use_list, *new_list;
 	bool bad_bb_order = 0;
 
+
 	/* Create a double-linked list of nodes ordered by BB, respecting BB->start and BB->end */
 	IR_ASSERT(_blocks[1] == 1);
-	prev_b = 1;
-	prev_b_end = ctx->cfg_blocks[1].end;
+
+	/* link BB boundaries */
 	_prev[1] = 0;
-	_prev[prev_b_end] = 0;
-	for (i = 2, j = 1; i < ctx->insns_count; i++) {
-		b = _blocks[i];
-		IR_ASSERT((int32_t)b >= 0);
-		if (b == prev_b && i <= prev_b_end) {
-			/* add to the end of the list */
-			_next[j] = i;
-			_prev[i] = j;
-			j = i;
-		} else if (b > prev_b) {
-			bb = &ctx->cfg_blocks[b];
-			if (i == bb->start) {
-				if (bb->end > bb->start) {
-					prev_b = b;
-					prev_b_end = bb->end;
-					/* add to the end of the list */
-					_next[j] = i;
-					_prev[i] = j;
-					j = i;
-				} else {
-					prev_b = 0;
-					prev_b_end = 0;
-					k = bb->end;
-					while (_blocks[_prev[k]] == b) {
-						k = _prev[k];
-					}
-					/* insert before "k" */
-					_prev[i] = _prev[k];
-					_next[i] = k;
-					_next[_prev[k]] = i;
-					_prev[k] = i;
-				}
-				if (!ir_is_good_bb_order(ctx, b, bb, i)) {
-					bad_bb_order = 1;
-				}
-			} else if (i != bb->end) {
-				/* move down late (see the following loop) */
-				_next[i] = _move_down;
-				_move_down = i;
-			} else {
-				prev_b = 0;
-				prev_b_end = 0;
-				if (bb->start > bb->end) {
-					/* add to the end of the list */
-					_next[j] = i;
-					_prev[i] = j;
-					j = i;
-				} else {
-					k = bb->start;
-					while (_blocks[_next[k]] == b) {
-						k = _next[k];
-					}
-					/* insert after "k" */
-					_next[i] = _next[k];
-					_prev[i] = k;
-					_prev[_next[k]] = i;
-					_next[k] = i;
-				}
-			}
-		} else if (b) {
-			bb = &ctx->cfg_blocks[b];
-			IR_ASSERT(i != bb->start);
-			if (i > bb->end) {
-				/* move up, insert before the end of the already scheduled BB */
-				k = bb->end;
-			} else {
-				IR_ASSERT(i > bb->start);
-				/* move up, insert at the end of the block */
-				k = ctx->cfg_blocks[b + 1].start;
-			}
-			/* insert before "k" */
-			_prev[i] = _prev[k];
-			_next[i] = k;
-			_next[_prev[k]] = i;
-			_prev[k] = i;
+	prev_b_end = ctx->cfg_blocks[1].end;
+	_next[1] = prev_b_end;
+	_prev[prev_b_end] = 1;
+	for (b = 2, bb = ctx->cfg_blocks + 2; b <= ctx->cfg_blocks_count; b++, bb++) {
+		_next[prev_b_end] = bb->start;
+		_prev[bb->start] = prev_b_end;
+		_next[bb->start] = bb->end;
+		_prev[bb->end] = bb->start;
+		prev_b_end = bb->end;
+		if (!ir_is_good_bb_order(ctx, b, bb, bb->start)) {
+			bad_bb_order = 1;
 		}
 	}
-	_next[j] = 0;
+	_next[prev_b_end] = 0;
 
-	while (_move_down) {
-		i = _move_down;
-		_move_down = _next[i];
+	/* insert intermediate BB nodes */
+	for (i = 2, j = 1; i < ctx->insns_count; i++) {
 		b = _blocks[i];
+		if (!b) continue;
 		bb = &ctx->cfg_blocks[b];
-		k = _next[bb->start];
-
-		if (bb->flags & (IR_BB_HAS_PHI|IR_BB_HAS_PI|IR_BB_HAS_PARAM|IR_BB_HAS_VAR)) {
-			/* insert after the start of the block and all PARAM, VAR, PI, PHI */
-			insn = &ctx->ir_base[k];
-			while (insn->op == IR_PHI || insn->op == IR_PARAM || insn->op == IR_VAR || insn->op == IR_PI) {
-				k = _next[k];
-				insn = &ctx->ir_base[k];
-			}
+		if (i != bb->start && i != bb->end) {
+			/* insert before "end" */
+			ir_ref n = bb->end;
+			ir_ref p = _prev[n];
+			_prev[i] = p;
+			_next[i] = n;
+			_next[p] = i;
+			_prev[n] = i;
 		}
+	}
 
-		/* insert before "k" */
-		_prev[i] = _prev[k];
-		_next[i] = k;
-		_next[_prev[k]] = i;
-		_prev[k] = i;
+	if (bad_bb_order) {
+		ir_fix_bb_order(ctx, _prev, _next);
 	}
 
 #ifdef IR_DEBUG
@@ -1051,10 +989,6 @@ int ir_schedule(ir_ctx *ctx)
 	}
 #endif
 
-	if (bad_bb_order) {
-		ir_fix_bb_order(ctx, _prev, _next);
-	}
-
 	_xlat = ir_mem_calloc((ctx->consts_count + ctx->insns_count), sizeof(ir_ref));
 	_xlat += ctx->consts_count;
 	_xlat[IR_TRUE] = IR_TRUE;
@@ -1168,7 +1102,11 @@ int ir_schedule(ir_ctx *ctx)
 			if (end->op == IR_IF) {
 				/* Move condition closer to IF */
 				input = end->op2;
-				if (input > 0 && _blocks[input] == b && !_xlat[input] && _prev[j] != input) {
+				if (input > 0
+				 && _blocks[input] == b
+				 && !_xlat[input]
+				 && _prev[j] != input
+				 && (!(ir_op_flags[ctx->ir_base[input].op] & IR_OP_FLAG_CONTROL) || end->op1 == input)) {
 					if (input == i) {
 						i = _next[i];
 						insn = &ctx->ir_base[i];
@@ -1188,6 +1126,7 @@ int ir_schedule(ir_ctx *ctx)
 			ir_ref n, j, *p, input;
 
 restart:
+			IR_ASSERT(_blocks[i] == b);
 			n = insn->inputs_count;
 			for (j = n, p = insn->ops + 1; j > 0; p++, j--) {
 				input = *p;
@@ -1221,6 +1160,7 @@ restart:
 			}
 			_xlat[i] = insns_count;
 			insns_count += ir_insn_inputs_to_len(n);
+			IR_ASSERT(_next[i] != IR_UNUSED);
 			i = _next[i];
 			insn = &ctx->ir_base[i];
 		}
@@ -1274,6 +1214,7 @@ restart:
 	new_ctx.insns_count = insns_count;
 	new_ctx.flags2 = ctx->flags2;
 	new_ctx.ret_type = ctx->ret_type;
+	new_ctx.value_params = ctx->value_params;
 	new_ctx.mflags = ctx->mflags;
 	new_ctx.spill_base = ctx->spill_base;
 	new_ctx.fixed_stack_red_zone = ctx->fixed_stack_red_zone;
@@ -1511,6 +1452,7 @@ restart:
 	new_ctx.cfg_edges = ctx->cfg_edges;
 	ctx->cfg_blocks = NULL;
 	ctx->cfg_edges = NULL;
+	ctx->value_params = NULL;
 	ir_code_buffer *saved_code_buffer = ctx->code_buffer;
 
 	ir_free(ctx);
