@@ -28,13 +28,14 @@
  * The following code is adopted from the PostgreSQL's ps_status(.h/.c).
  */
 
+#include <php.h>
 #ifdef PHP_WIN32
 #include "config.w32.h"
 #include <windows.h>
 #include <process.h>
 #include "win32/codepage.h"
 #else
-#include "php_config.h"
+#include <php_config.h>
 extern char** environ;
 #endif
 
@@ -57,7 +58,7 @@ extern char** environ;
 #include <machine/vmparam.h> /* for old BSD */
 #include <sys/exec.h>
 #endif
-#if defined(DARWIN)
+#if defined(__APPLE__)
 #include <crt_externs.h>
 #endif
 
@@ -91,9 +92,9 @@ extern char** environ;
 #define PS_USE_PSTAT
 #elif defined(HAVE_PS_STRINGS)
 #define PS_USE_PS_STRINGS
-#elif defined(BSD) && !defined(DARWIN)
+#elif defined(BSD) && !defined(__APPLE__)
 #define PS_USE_CHANGE_ARGV
-#elif defined(__linux__) || defined(_AIX) || defined(__sgi) || (defined(sun) && !defined(BSD)) || defined(ultrix) || defined(__osf__) || defined(DARWIN)
+#elif defined(__linux__) || defined(_AIX) || defined(__sgi) || (defined(sun) && !defined(BSD)) || defined(ultrix) || defined(__osf__) || defined(__APPLE__)
 #define PS_USE_CLOBBER_ARGV
 #elif defined(PHP_WIN32)
 #define PS_USE_WIN32
@@ -102,7 +103,7 @@ extern char** environ;
 #endif
 
 /* Different systems want the buffer padded differently */
-#if defined(_AIX) || defined(__linux__) || defined(DARWIN)
+#if defined(_AIX) || defined(__linux__) || defined(__APPLE__)
 #define PS_PADDING '\0'
 #else
 #define PS_PADDING ' '
@@ -235,7 +236,7 @@ char** save_ps_args(int argc, char** argv)
         }
         new_argv[argc] = NULL;
 
-#if defined(DARWIN)
+#if defined(__APPLE__)
         /*
          * Darwin (and perhaps other NeXT-derived platforms?) has a static
          * copy of the argv pointer, which we may fix like so:
@@ -321,7 +322,7 @@ const char* ps_title_errno(int rc)
 
 #ifdef PS_USE_WIN32
     case PS_TITLE_WINDOWS_ERROR:
-        sprintf(windows_error_details, "Windows error code: %lu", GetLastError());
+        snprintf(windows_error_details, sizeof(windows_error_details), "Windows error code: %lu", GetLastError());
         return windows_error_details;
 #endif
     }
@@ -342,9 +343,8 @@ int set_ps_title(const char* title)
     if (rc != PS_TITLE_SUCCESS)
         return rc;
 
-    strncpy(ps_buffer, title, ps_buffer_size);
-    ps_buffer[ps_buffer_size - 1] = '\0';
-    ps_buffer_cur_len = strlen(ps_buffer);
+    size_t title_len = strlcpy(ps_buffer, title, ps_buffer_size);
+    ps_buffer_cur_len = (title_len >= ps_buffer_size) ? ps_buffer_size - 1 : title_len;
 
 #ifdef PS_USE_SETPROCTITLE
     setproctitle("%s", ps_buffer);
